Module codec

Module codec 

Discriminating codec for multiplexing discv4 and discv5 on a shared UDP socket.

This codec simply passes through raw bytes - the actual protocol discrimination happens in the multiplexer based on the keccak hash check.

Structs

DiscriminatingCodec
A codec that passes through raw bytes for the multiplexer to process. The actual protocol discrimination happens in the multiplexer.
RawPacket
A raw packet received from the UDP socket.