pub struct FindNodeRequest {
pub nodes_sent: u64,
pub sent_at: u64,
pub tx: Option<UnboundedSender<Vec<Node>>>,
}Fields
nodes_sent: u64the number of nodes sent we keep track of this number since we will accept neighbor messages until the max_per_bucket
sent_at: u64unix timestamp tracking when we have sent the request
tx: Option<UnboundedSender<Vec<Node>>>if present, server will send the nodes through this channel when receiving neighbors useful to wait for the response in lookups
Implementations
Sourceimpl FindNodeRequest
impl FindNodeRequest
pub fn new_with_sender(sender: UnboundedSender<Vec<Node>>) -> Self