Contact

Struct Contact 

pub struct Contact {
    pub node: Node,
    pub is_discv4: bool,
    pub is_discv5: bool,
    pub validation_timestamp: Option<Instant>,
    pub ping_id: Option<Bytes>,
    pub enr_request_hash: Option<H256>,
    pub record: Option<NodeRecord>,
    pub disposable: bool,
    pub knows_us: bool,
    pub unwanted: bool,
    pub is_fork_id_valid: Option<bool>,
    /* private fields */
}

Fields

node: Nodeis_discv4: bool

Whether this contact is reachable via discv4 protocol.

is_discv5: bool

Whether this contact is reachable via discv5 protocol.

validation_timestamp: Option<Instant>

The timestamp when the contact was last sent a ping. If None, the contact has never been pinged.

ping_id: Option<Bytes>

The identifier of the last unacknowledged ping sent to this contact, or None if no ping was sent yet or it was already acknowledged.

  • discv4: H256 hash converted to Bytes
  • discv5: request ID as Bytes
enr_request_hash: Option<H256>

The hash of the last unacknowledged ENRRequest sent to this contact, or None if no request was sent yet or it was already acknowledged.

record: Option<NodeRecord>

ENR associated with this contact, if it was provided by the peer.

disposable: bool

This contact failed to respond our Ping.

knows_us: bool

Set to true after we send a successful ENRResponse to it.

unwanted: bool

This is a known-bad peer (on another network, no matching capabilities, etc)

is_fork_id_valid: Option<bool>

Whether the last known fork ID is valid, None if unknown.

Implementations

Source

impl Contact

pub fn was_validated(&self) -> bool

pub fn has_pending_ping(&self) -> bool

pub fn record_ping_sent(&mut self, ping_id: Bytes)

pub fn record_enr_request_sent(&mut self, request_hash: H256)

pub fn record_enr_response_received( &mut self, request_hash: H256, record: NodeRecord, )

pub fn has_pending_enr_request(&self) -> bool

Source

impl Contact

pub fn new(node: Node, protocol: DiscoveryProtocol) -> Self

pub fn supports_protocol(&self, protocol: DiscoveryProtocol) -> bool

Check if this contact supports the given protocol.

pub fn add_protocol(&mut self, protocol: DiscoveryProtocol)

Mark this contact as supporting the given protocol.