pub struct PeerData {
pub node: Node,
pub record: Option<NodeRecord>,
pub supported_capabilities: Vec<Capability>,
pub is_connection_inbound: bool,
pub connection: Option<PeerConnection>,
pub last_response_time: Option<u64>,
/* private fields */
}Fields
node: Noderecord: Option<NodeRecord>supported_capabilities: Vec<Capability>is_connection_inbound: boolSet to true if the connection is inbound (aka the connection was started by the peer and not by this node) It is only valid as long as is_connected is true
connection: Option<PeerConnection>communication channels between the peer data and its active connection
last_response_time: Option<u64>Timestamp (seconds since UNIX epoch) of the last successful response from this peer
Implementations
Sourceimpl PeerData
impl PeerData
pub fn new( node: Node, record: Option<NodeRecord>, connection: Option<PeerConnection>, capabilities: Vec<Capability>, ) -> Self