Module sync

Module sync 

Sync module - orchestrates full and snap synchronization

This module provides the main Syncer type that coordinates synchronization between full sync mode (all blocks executed) and snap sync mode (state fetched via snap protocol).

Structs

AccountStorageRoots
We store for optimization the accounts that need to heal storage
PivotChangeEvent
SnapBlockSyncState
Persisted State during the Block Sync phase for SnapSync
SyncDiagnostics
Diagnostic snapshot of the sync state, used by admin RPC endpoints.
SyncErrorEvent
Syncer
Manager in charge the sync process

Enums

SyncError
SyncMode

Functions

block_is_stale
calculate_staleness_timestamp
update_pivot
validate_bytecodes
validate_state_root
validate_storage_root