pub struct AccountStorageRoots {
pub accounts_with_storage_root: BTreeMap<H256, (Option<H256>, Vec<(H256, H256)>)>,
pub healed_accounts: HashSet<H256>,
}Expand description
We store for optimization the accounts that need to heal storage
Fields
accounts_with_storage_root: BTreeMap<H256, (Option<H256>, Vec<(H256, H256)>)>The accounts that have not been healed are guaranteed to have the original storage root we can read this storage root
healed_accounts: HashSet<H256>If an account has been healed, it may return to a previous state, so we just store the account in a hashset