pub struct SnapBlockSyncState {
pub block_hashes: Vec<H256>,
/* private fields */
}Expand description
Persisted State during the Block Sync phase for SnapSync
Fields
block_hashes: Vec<H256>Implementations
Sourceimpl SnapBlockSyncState
impl SnapBlockSyncState
pub fn new(store: Store) -> Self
Sourcepub async fn get_current_head(&self) -> Result<H256, SyncError>
pub async fn get_current_head(&self) -> Result<H256, SyncError>
Obtain the current head from where to start or resume block sync
Sourcepub async fn process_incoming_headers(
&mut self,
block_headers: impl Iterator<Item = BlockHeader>,
) -> Result<(), SyncError>
pub async fn process_incoming_headers( &mut self, block_headers: impl Iterator<Item = BlockHeader>, ) -> Result<(), SyncError>
Stores incoming headers to the Store and saves their hashes