pub struct Syncer { /* private fields */ }Expand description
Manager in charge the sync process
Implementations
Sourceimpl Syncer
impl Syncer
pub fn new( peers: PeerHandler, snap_enabled: Arc<AtomicBool>, cancel_token: CancellationToken, blockchain: Arc<Blockchain>, datadir: PathBuf, diagnostics: Arc<RwLock<SyncDiagnostics>>, ) -> Self
Sourcepub async fn start_sync(&mut self, sync_head: H256, store: Store)
pub async fn start_sync(&mut self, sync_head: H256, store: Store)
Starts a sync cycle, updating the state with all blocks between the current head and the sync head
Will perform either full or snap sync depending on the manager’s snap_mode
In full mode, all blocks will be fetched via p2p eth requests and executed to rebuild the state
In snap mode, blocks and receipts will be fetched and stored in parallel while the state is fetched via p2p snap requests
After the sync cycle is complete, the sync mode will be set to full
If the sync fails, no error will be returned but a warning will be emitted
[WARNING] Sync is done optimistically, so headers and bodies may be stored even if their data has not been fully synced if the sync is aborted halfway
[WARNING] Sync is currenlty simplified and will not download bodies + receipts previous to the pivot during snap sync