pub struct SyncManager { /* private fields */ }Expand description
Abstraction to interact with the active sync process without disturbing it
Implementations
Sourceimpl SyncManager
impl SyncManager
pub async fn new( peer_handler: PeerHandler, sync_mode: &SyncMode, cancel_token: CancellationToken, blockchain: Arc<Blockchain>, store: Store, datadir: PathBuf, ) -> Self
Sourcepub fn sync_to_head(&self, fcu_head: H256)
pub fn sync_to_head(&self, fcu_head: H256)
Sets the latest fcu head and starts the next sync cycle if the syncer is currently inactive
Sourcepub fn sync_mode(&self) -> SyncMode
pub fn sync_mode(&self) -> SyncMode
Returns the syncer’s current syncmode (either snap or full)
Sourcepub fn disable_snap(&self)
pub fn disable_snap(&self)
Disables snapsync mode
Sourcepub async fn get_sync_diagnostics(&self) -> SyncDiagnostics
pub async fn get_sync_diagnostics(&self) -> SyncDiagnostics
Returns a snapshot of the current sync diagnostics with live values.
Sourcepub fn diagnostics(&self) -> &Arc<RwLock<SyncDiagnostics>> ⓘ
pub fn diagnostics(&self) -> &Arc<RwLock<SyncDiagnostics>> ⓘ
Returns a reference to the diagnostics RwLock for updating from the sync code.
pub fn get_last_fcu_head(&self) -> Result<H256, TryLockError>