Structs
- Accounts
With Storage - Struct representing the storage slots of certain accounts that share the same storage root
Functions
- current_
unix_ time - delete_
leaves_ folder - Deletes the snap folders needed for downloading the leaves during the initial step of snap sync.
- distance
- Computes the distance between two nodes according to the discv4/5 protocols https://github.com/ethereum/devp2p/blob/master/discv4.md#node-identities https://github.com/ethereum/devp2p/blob/master/discv5/discv5-theory.md#nodes-records-and-distances
- dump_
accounts_ to_ file - dump_
storages_ to_ file - dump_
to_ file - get_
account_ state_ snapshot_ file - get_
account_ state_ snapshots_ dir - get_
account_ storages_ snapshot_ file - get_
account_ storages_ snapshots_ dir - get_
code_ hashes_ snapshot_ file - get_
code_ hashes_ snapshots_ dir - get_
msg_ expiration_ from_ seconds - get_
rocksdb_ temp_ accounts_ dir - get_
rocksdb_ temp_ storage_ dir - is_
msg_ expired - node_id
- Computes the node_id from a public key (aka computes the Keccak256 hash of the given public key)
- public_
key_ from_ signing_ key