pub struct IterativeLookup {
pub target: H256,
/* private fields */
}Expand description
Iterative convergence lookup (geth-style).
Generates a random target, seeds with closest known nodes, queries alpha=3 closest not-yet-asked nodes, feeds responses back, and iterates until convergence (no more unqueried entries closer than what we have, or timeout).
Fields
target: H256Implementations
Sourceimpl IterativeLookup
impl IterativeLookup
Sourcepub fn new(target: H256, seed_nodes: Vec<(H256, Node)>) -> Self
pub fn new(target: H256, seed_nodes: Vec<(H256, Node)>) -> Self
Create a new iterative lookup seeded with the given nodes.
Sourcepub fn next_to_query(&mut self, count: usize) -> Vec<(H256, Node)>
pub fn next_to_query(&mut self, count: usize) -> Vec<(H256, Node)>
Returns up to count closest unqueried entries, marks them as queried,
and increments the in-flight counter.
Sourcepub fn feed_results(&mut self, nodes: Vec<(H256, Node)>)
pub fn feed_results(&mut self, nodes: Vec<(H256, Node)>)
Feed response nodes into the lookup. Inserts new nodes if they are
closer than the farthest entry (or the result set is not full yet).
Deduplicates via the seen set.
Sourcepub fn record_response(&mut self)
pub fn record_response(&mut self)
Record that a response was received (decrements in-flight counter).
Sourcepub fn record_timeout(&mut self)
pub fn record_timeout(&mut self)
Record that a query timed out (same as record_response).
Sourcepub fn is_finished(&self) -> bool
pub fn is_finished(&self) -> bool
Returns true if the lookup has converged:
- All entries in the result set have been queried (don’t wait for stragglers — late responses still get processed via handle_neighbors and feed into the connection pool / next lookup), OR
- The lookup has timed out.