Sync module - orchestrates full and snap synchronization
This module provides the main Syncer type that coordinates synchronization
between full sync mode (all blocks executed) and snap sync mode (state fetched
via snap protocol).
Structs
- Account
Storage Roots - We store for optimization the accounts that need to heal storage
- Pivot
Change Event - Snap
Block Sync State - Persisted State during the Block Sync phase for SnapSync
- Sync
Diagnostics - Diagnostic snapshot of the sync state, used by admin RPC endpoints.
- Sync
Error Event - Syncer
- Manager in charge the sync process